@@ -30,7 +30,7 @@ def get_bootstrap_osd_key(cluster):
         raise RuntimeError('bootstrap-osd keyring not found; run \'gatherkeys\'')
 
 
-def create_osd(conn, cluster, key):
+def create_osd_keyring(conn, cluster, key):
     """
     Run on osd node, writes the bootstrap key if not there yet.
     """
@@ -107,8 +107,9 @@ def osd_status_check(conn, cluster):
     Note how the booleans are actually strings, so we need to take that into
     account and fix it before returning the dictionary. Issue #8108
     """
+    ceph_executable = system.executable_path(conn, 'ceph')
     command = [
-        'ceph',
+        ceph_executable,
         '--cluster={cluster}'.format(cluster=cluster),
         'osd',
         'stat',
@@ -187,12 +188,14 @@ def prepare_disk(
         zap,
         fs_type,
         dmcrypt,
-        dmcrypt_dir):
+        dmcrypt_dir,
+        storetype):
     """
     Run on osd node, prepares a data disk for use.
     """
+    ceph_disk_executable = system.executable_path(conn, 'ceph-disk')
     args = [
-        'ceph-disk',
+        ceph_disk_executable,
         '-v',
         'prepare',
         ]
@@ -203,6 +206,8 @@ def prepare_disk(
         if dmcrypt_dir is not None:
             args.append('--dmcrypt-key-dir')
             args.append(dmcrypt_dir)
+    if storetype:
+        args.append('--' + storetype)
     args.extend([
         '--cluster',
         cluster,
@@ -305,11 +310,15 @@ def prepare(args, cfg, activate_prepared_disk):
                     args.overwrite_conf
                 )
 
-                create_osd(distro.conn, args.cluster, key)
+                create_osd_keyring(distro.conn, args.cluster, key)
 
             LOG.debug('Preparing host %s disk %s journal %s activate %s',
                       hostname, disk, journal, activate_prepared_disk)
 
+            storetype = None
+            if args.bluestore:
+                storetype = 'bluestore'
+
             prepare_disk(
                 distro.conn,
                 cluster=args.cluster,
@@ -321,6 +330,7 @@ def prepare(args, cfg, activate_prepared_disk):
                 fs_type=args.fs_type,
                 dmcrypt=args.dmcrypt,
                 dmcrypt_dir=args.dmcrypt_key_dir,
+                storetype=storetype,
             )
 
             # give the OSD a few seconds to start
@@ -363,10 +373,11 @@ def activate(args, cfg):
         LOG.debug('activating host %s disk %s', hostname, disk)
         LOG.debug('will use init type: %s', distro.init)
 
+        ceph_disk_executable = system.executable_path(distro.conn, 'ceph-disk')
         remoto.process.run(
             distro.conn,
             [
-                'ceph-disk',
+                ceph_disk_executable,
                 '-v',
                 'activate',
                 '--mark-init',
@@ -417,32 +428,6 @@ def disk_zap(args):
             ],
         )
 
-        # once all is done, call partprobe (or partx)
-        # On RHEL and CentOS distros, calling partprobe forces a reboot of the
-        # server. Since we are not resizing partitons we rely on calling
-        # partx
-        if distro.normalized_name.startswith(('centos', 'red')):
-            LOG.info('calling partx on zapped device %s', disk)
-            LOG.info('re-reading known partitions will display errors')
-            remoto.process.run(
-                distro.conn,
-                [
-                    'partx',
-                    '-a',
-                    disk,
-                ],
-            )
-
-        else:
-            LOG.debug('Calling partprobe on zapped device %s', disk)
-            remoto.process.run(
-                distro.conn,
-                [
-                    'partprobe',
-                    disk,
-                ],
-            )
-
         distro.conn.exit()
 
 
@@ -695,11 +680,10 @@ def make(parser):
         '--fs-type',
         metavar='FS_TYPE',
         choices=['xfs',
-                 'ext4',
                  'btrfs'
                  ],
         default='xfs',
-        help='filesystem to use to format DISK (xfs, btrfs, or ext4)',
+        help='filesystem to use to format DISK (xfs, btrfs)',
         )
     osd_create.add_argument(
         '--dmcrypt',
@@ -712,6 +696,11 @@ def make(parser):
         default='/etc/ceph/dmcrypt-keys',
         help='directory where dm-crypt keys are stored',
         )
+    osd_create.add_argument(
+        '--bluestore',
+        action='store_true', default=None,
+        help='bluestore objectstore',
+        )
     osd_create.add_argument(
         'disk',
         nargs='+',
@@ -733,11 +722,10 @@ def make(parser):
         '--fs-type',
         metavar='FS_TYPE',
         choices=['xfs',
-                 'ext4',
                  'btrfs'
                  ],
         default='xfs',
-        help='filesystem to use to format DISK (xfs, btrfs, or ext4)',
+        help='filesystem to use to format DISK (xfs, btrfs)',
         )
     osd_prepare.add_argument(
         '--dmcrypt',
@@ -750,6 +738,11 @@ def make(parser):
         default='/etc/ceph/dmcrypt-keys',
         help='directory where dm-crypt keys are stored',
         )
+    osd_prepare.add_argument(
+        '--bluestore',
+        action='store_true', default=None,
+        help='bluestore objectstore',
+        )
     osd_prepare.add_argument(
         'disk',
         nargs='+',
@@ -818,11 +811,10 @@ def make_disk(parser):
         '--fs-type',
         metavar='FS_TYPE',
         choices=['xfs',
-                 'ext4',
                  'btrfs'
                  ],
         default='xfs',
-        help='filesystem to use to format DISK (xfs, btrfs, or ext4)',
+        help='filesystem to use to format DISK (xfs, btrfs)',
         )
     disk_prepare.add_argument(
         '--dmcrypt',
@@ -835,6 +827,11 @@ def make_disk(parser):
         default='/etc/ceph/dmcrypt-keys',
         help='directory where dm-crypt keys are stored',
         )
+    disk_prepare.add_argument(
+        '--bluestore',
+        action='store_true', default=None,
+        help='bluestore objectstore',
+        )
     disk_prepare.add_argument(
         'disk',
         nargs='+',
